@@ -1,3 +1,28 @@
+# ScribeHandler is a simple proxy layer that works with the python standard
+# logging module (http://docs.python.org/library/logging.html).  ScribeHandler
+# acts a a handler object that gets added to a logger in the standard way.
+# Copyright (C) 2010 Jeremy Jones
+#
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License along
+#    with this program; if not, write to the Free Software Foundation, Inc.,
+#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#
+# Contact the author:
+# http://www.letifer.org
+# http://github.com/ScribeHandler
+# jeremyj (at) letifer (dot) org
+
+
 import logging, socket
 
 from urlparse import urlparse
@@ -67,11 +92,18 @@ class ScribeHandler(logging.Handler):
         if (self.client is None) or (self.transport is None):
             raise ScribeTransportError('No transport defined')
 
+        # It looks like pypy Does not have logging.logRecord.processName
+        # This is a hackish workaround.
+        if hasattr(record, 'processName'):
+            pn = record.processName
+        else:
+            pn = 'Unknown'
+
         category = self.category % {
             'module' : record.module,
             'levelname': record.levelname,
             'loggername' : record.name,
-            'processName' : record.processName,
+            'processName' : pn,
             'hostname' : socket.gethostname(),
         }
 
@@ -86,6 +118,6 @@ class ScribeHandler(logging.Handler):
             if result != scribe.ResultCode.OK:
                 raise ScribeLogError(result)
         except:
-            self.raiseException(record)
+            self.handleError(record)
 
 
